@@ -3,6 +3,6 @@
 #' @param message Message that should be printed to R console
 log_msg <- function(message) {
   if (getOption("xspliner.log", default = FALSE)) {
-    cat(message)
+    cat(message, "\n")
   }
 }
